<?php

namespace Property\Property\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Property\Property\Http\Requests\PropertyAdminRequest;
use Property\Property\Interfaces\PropertyRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class PropertyAdminController extends AdminController
{
    /**
     * Initialize property controller.
     *
     * @param type PropertyRepositoryInterface $property
     *
     * @return type
     */
    public function __construct(PropertyRepositoryInterface $property)
    {
        $this->model = $property;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(PropertyAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('property.property.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('property::property.names').' :: ');

        return $this->theme->of('property::admin.property.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(PropertyAdminRequest $request, $id)
    {
        $property = $this->model->find($id);

        if (empty($property)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('property::admin.property.new');
        }

        if ($request->wantsJson()) {
            return $property;
        }

        Former::populate($property);

        return view('property::admin.property.show', compact('property'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PropertyAdminRequest $request)
    {
        $property = $this->model->findOrNew(0);
        Former::populate($property);

        return view('property::admin.property.create', compact('property'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PropertyAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $property = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('property::property.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(PropertyAdminRequest $request, $id)
    {
        $property = $this->model->find($id);

        Former::populate($property);

        return view('property::admin.property.edit', compact('property'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(PropertyAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $property = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('property::property.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(PropertyAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('property::property.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
