<?php

namespace Property\Property\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Property\Property\Http\Requests\PropertyUserRequest;
use Property\Property\Interfaces\PropertyRepositoryInterface;
use Response;
use User;

class PropertyUserController extends UserController
{
    /**
     * Initialize property controller.
     *
     * @param type PropertyRepositoryInterface $property
     *
     * @return type
     */
    public function __construct(PropertyRepositoryInterface $property)
    {
        $this->model = $property;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(PropertyUserRequest $request)
    {
        $properties = $this->model->all();

        $this->theme->prependTitle(trans('property::property.names').' :: ');

        return $this->theme->of('property::user.property.index', compact('properties'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(PropertyUserRequest $request, $role, $id)
    {
        $property = $this->model->find($id);

        return $this->theme->of('property::user.property.show', compact('property'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PropertyUserRequest $request)
    {
        $property = $this->model->findOrNew(0);

        Former::populate($property);

        return $this->theme->of('property::user.property.create', compact('property'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PropertyUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $property = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('property::property.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(PropertyUserRequest $request, $role, $id)
    {
        $property = $this->model->find($id);

        Former::populate($property);

        return $this->theme->of('property::user.property.edit', compact('property'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(PropertyUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $property = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('property::property.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(PropertyUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('property::property.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
